@@ -13,11 +13,7 @@
 #include <QEventLoop>
 #include <QIODevice>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <qt5keychain/keychain.h>
-#else
 #include <qt6keychain/keychain.h>
-#endif
 
 #include <KGAPI/AuthJob>
 #include <KIO/Job> //for stat.h
